@@ -5,23 +5,44 @@ from .settings import azure_rm_endpoint, COMP_API, NETWORK_API
 import json
 
 
+# create_as(access_token, subscription_id, resource_group, as_name, \
+#   update_domains, fault_domains, location)
+# create availability set
+def create_as(access_token, subscription_id, resource_group, as_name,
+              update_domains, fault_domains, location):
+
+    endpoint = ''.join([azure_rm_endpoint,
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/availabilitySets/', as_name,
+                        '?api-version=', COMP_API])
+    as_body = {'location': location}
+    properties = {'platformUpdateDomainCount': update_domains}
+    properties['platformFaultDomainCount'] = fault_domains
+    as_body['properties'] = properties
+    body = json.dumps(as_body)
+    return do_put(endpoint, body, access_token)
+
+
 # create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, publisher, offer, sku, version,
-#              storage_account, os_uri, nic_id, location, username='azure', password=None, public_key=None)
+#              nic_id, location, storage_type='standard_LRS', username='azure', password=None, public_key=None)
 # create a simple virtual machine - in most cases deploying an ARM template might be easier
 def create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, publisher, offer, sku, version,
-              storage_account, os_uri, nic_id, location, username='azure', password=None, public_key=None):
+              nic_id, location, storage_type='Standard_LRS', osdisk_name=None, username='azure', password=None, public_key=None):
     endpoint = ''.join([azure_rm_endpoint,
                 '/subscriptions/', subscription_id,
                 '/resourceGroups/', resource_group,
                 '/providers/Microsoft.Compute/virtualMachines/', vm_name,
                 '?api-version=', COMP_API])
+    if osdisk_name is None:
+        osdisk_name = vm_name + 'osdisk'
     vm_body = {'name': vm_name}
     vm_body['location'] = location
     properties = {'hardwareProfile': {'vmSize': vm_size}}
     image_reference = {'publisher': publisher, 'offer': offer, 'sku': sku, 'version': version}
     storage_profile = {'imageReference': image_reference}
-    os_disk = {'name': 'osdisk1'}
-    os_disk['vhd'] = {'uri': os_uri}
+    os_disk = {'name': osdisk_name}
+    os_disk['managedDisk'] = {'storageAccountType': storage_type}
     os_disk['caching'] = 'ReadWrite'
     os_disk['createOption'] = 'fromImage'
     storage_profile['osDisk'] = os_disk
@@ -49,13 +70,13 @@ def create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, p
 
 
 # create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_size, capacity, \
-#   publisher, offer, sku, version, storage_container_list, subnet_id, be_pool_id, lb_pool_id, \
-#   location, username='azure', password=None, public_key=None, overprovision='true', \
+#   publisher, offer, sku, version, subnet_id, be_pool_id, lb_pool_id, \
+#   location, storage_type='Standard_LRS', username='azure', password=None, public_key=None, overprovision='true', \
 #   upgradePolicy='Manual')
 # create virtual machine scale set
 def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_size, capacity, \
-    publisher, offer, sku, version, storage_container_list, subnet_id, be_pool_id, lb_pool_id, \
-    location, username='azure', password=None, public_key=None, overprovision='true', \
+    publisher, offer, sku, version, subnet_id, be_pool_id, lb_pool_id, location, storage_type='Standard_LRS', \
+     username='azure', password=None, public_key=None, overprovision='true', \
     upgradePolicy='Manual'):
     endpoint = ''.join([azure_rm_endpoint,
                 '/subscriptions/', subscription_id,
@@ -83,10 +104,9 @@ def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_siz
         linux_config['ssh'] = {'publicKeys': [pub_key]}
         os_profile['linuxConfiguration'] = linux_config
     vm_profile = {'osProfile': os_profile}
-    os_disk = {'name': vmss_name}
-    os_disk['vhdContainers'] = storage_container_list
+    os_disk = {'createOption': 'fromImage'}
+    os_disk['managedDisk'] = {'storageAccountType': storage_type}
     os_disk['caching'] = 'ReadWrite'
-    os_disk['createOption'] = 'FromImage'
     storage_profile = {'osDisk': os_disk}
     storage_profile['imageReference'] = \
         {'publisher': publisher, 'offer': offer, 'sku': sku, 'version': version} 
@@ -119,6 +139,17 @@ def deallocate_vm(access_token, subscription_id, resource_group, vm_name):
     return do_post(endpoint, '', access_token)
 
 
+# delete_as(access_token, subscription_id, resource_group, as_name)
+# delete availability set
+def delete_as(access_token, subscription_id, resource_group, as_name):
+    endpoint = ''.join([azure_rm_endpoint,
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/availabilitySets/', as_name,
+                        '?api-version=', COMP_API])
+    return do_delete(endpoint, access_token)
+
+
 # delete_vm(access_token, subscription_id, resource_group, vm_name)
 # delete a virtual machine
 def delete_vm(access_token, subscription_id, resource_group, vm_name):
@@ -266,6 +297,17 @@ def get_vmss_vm_nics(access_token, subscription_id, resource_group, vmss_name, i
     return do_get(endpoint, access_token)
 
 
+# get_as(access_token, subscription_id, resource_group, as_name)
+# get availability set
+def get_as(access_token, subscription_id, resource_group, as_name):
+    endpoint = ''.join([azure_rm_endpoint,
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/availabilitySets/', as_name,
+                        '?api-version=', COMP_API])
+    return do_get(endpoint, access_token)
+
+
 # list_as_sub(access_token, subscription_id, resource_group)
 # list availability sets in a resource_group
 def list_as(access_token, subscription_id, resource_group):
