@@ -38,7 +38,7 @@ def create_lb_with_nat_pool(access_token, subscription_id, resource_group, lb_na
 
 # create_nic(access_token, subscription_id, resource_group, nic_name, public_ip_id, subnet_id, location)
 # create a network interface with an associated public ip address
-def create_nic(access_token, subscription_id, resource_group, nic_name, public_ip_id, subnet_id, location):
+def create_nic(access_token, subscription_id, resource_group, nic_name, public_ip_id, subnet_id, location, nsg_id=None):
     endpoint = ''.join([azure_rm_endpoint,
                     '/subscriptions/', subscription_id,
                     '/resourceGroups/', resource_group,
@@ -51,6 +51,8 @@ def create_nic(access_token, subscription_id, resource_group, nic_name, public_i
     ipc_properties['subnet'] = {'id': subnet_id}
     ipconfig['properties'] = ipc_properties
     properties = {'ipConfigurations': [ipconfig]}
+    if nsg_id is not None:
+        properties['networkSecurityGroup'] = {'id': nsg_id}
     nic_body['properties'] = properties
     body = json.dumps(nic_body)
     return do_put(endpoint, body, access_token)
@@ -340,6 +342,17 @@ def list_vnets(access_token, subscription_id):
                         '/virtualNetworks?api-version=', NETWORK_API])
     return do_get(endpoint, access_token)
 
+
+# list_vnets_rg(access_token, subscription_id)
+# list the VNETs in a resource group
+def list_vnets_rg(access_token, subscription_id, resource_group):
+    endpoint = ''.join([azure_rm_endpoint,
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Network/',
+                        '/virtualNetworks?api-version=', NETWORK_API])
+    return do_get(endpoint, access_token)
+
     
 # update_load_balancer(access_token, subscription_id, resource_group, lb_name, body)
 # updates a load balancer model, i.e. PUT an updated LB body
